==> vue-components-1.6.3.tgz: package/lib/spinners/src/AbsoluteLoader.vue.rd.js <==
import { defineComponent as p, toRefs as d, computed as u, openBlock as t, createBlock as a, Transition as c, withCtx as m, unref as f, createElementBlock as o, renderSlot as b, createVNode as y, createCommentVNode as s, normalizeClass as k, toDisplayString as h } from "vue";
import w from "../loaders/DotsSpinning.vue.rd.js";
import { absoluteLoaderProps as _ } from "./props.rd.js";
import g from "./Spinner.vue.rd.js";
const z = {
  key: 0,
  class: "w-full r-absolute-loader h-full absolute top-0 left-0 bg-white dark:bg-slate-800 !bg-opacity-80 z-10 !m-0",
  style: { "backdrop-filter": "blur(2px)" }
}, C = {
  key: 0,
  class: "absolute-center"
}, v = {
  key: 1,
  class: "absolute-center"
}, N = /* @__PURE__ */ p({
  __name: "AbsoluteLoader",
  props: _(),
  setup(n) {
    const i = n, { loading: r } = d(i), l = u(() => r == null ? void 0 : r.value);
    return (e, S) => (t(), a(c, {
      name: "fade",
      mode: "out-in",
      appear: ""
    }, {
      default: m(() => [
        f(l) ? (t(), o("div", z, [
          e.$slots.default ? (t(), o("div", C, [
            b(e.$slots, "default")
          ])) : e.type === "dots" ? (t(), o("div", v, [
            y(w, { class: "mb-3" })
          ])) : e.type == "spinner" ? (t(), a(g, {
            key: 2,
            size: e.spinnerSize,
            loading: !0,
            inherit: !0,
            class: "text-primary-500 absolute-center dark:text-white"
          }, null, 8, ["size"])) : s("", !0),
          e.description ? (t(), o("span", {
            key: 3,
            class: k(["whitespace-nowrap mt-10 font-bold absolute-center text-primary-700 dark:text-primary-500", [e.descriptionClass]])
          }, h(e.description), 3)) : s("", !0)
        ])) : s("", !0)
      ]),
      _: 3
    }));
  }
});
export {
  N as default
};

==> vue-components-1.6.13.tgz: package/lib/spinners/src/AbsoluteLoader.vue.rd.js <==
import { defineComponent as p, toRefs as d, computed as u, openBlock as t, createBlock as a, Transition as c, withCtx as m, unref as f, createElementBlock as o, renderSlot as b, createVNode as y, createCommentVNode as s, normalizeClass as k, toDisplayString as h } from "vue";
import w from "../loaders/DotsSpinning.vue.rd.js";
import { absoluteLoaderProps as _ } from "./props.rd.js";
import g from "./Spinner.vue.rd.js";
const z = {
  key: 0,
  class: "w-full r-absolute-loader h-full absolute top-0 left-0 bg-white dark:bg-slate-800 !bg-opacity-80 z-10 !m-0",
  style: { "backdrop-filter": "blur(2px)" }
}, C = {
  key: 0,
  class: "absolute-center"
}, v = {
  key: 1,
  class: "absolute-center"
}, N = /* @__PURE__ */ p({
  __name: "AbsoluteLoader",
  props: _(),
  setup(n) {
    const i = n, { loading: r } = d(i), l = u(() => r == null ? void 0 : r.value);
    return (e, S) => (t(), a(c, {
      name: "fade",
      mode: "out-in",
      appear: ""
    }, {
      default: m(() => [
        f(l) ? (t(), o("div", z, [
          e.$slots.default ? (t(), o("div", C, [
            b(e.$slots, "default")
          ])) : e.type === "dots" ? (t(), o("div", v, [
            y(w, { class: "mb-3 text-primary-600" })
          ])) : e.type == "spinner" ? (t(), a(g, {
            key: 2,
            size: e.spinnerSize,
            loading: !0,
            inherit: !0,
            class: "text-primary-500 absolute-center dark:text-white"
          }, null, 8, ["size"])) : s("", !0),
          e.description ? (t(), o("span", {
            key: 3,
            class: k(["whitespace-nowrap mt-10 font-bold absolute-center text-primary-700 dark:text-primary-500", [e.descriptionClass]])
          }, h(e.description), 3)) : s("", !0)
        ])) : s("", !0)
      ]),
      _: 3
    }));
  }
});
export {
  N as default
};
